@@ -33,7 +33,9 @@ class Job:
         items=None,
         count=None,
     ):
+        self._id = id
         self._name = name
+        self._executions = executions
         self._href = href
 
     @classmethod
@@ -45,6 +47,14 @@ class Job:
     def name(self):
         return self._name
 
+    @property
+    def id(self):
+        return self._id
+
+    @property
+    def executions(self):
+        return self._executions
+
     @property
     def href(self):
         return self._href
