@@ -15,7 +15,7 @@
 #
 
 from hsfs import client
-from hsfs.core import fs_query
+from hsfs.constructor import fs_query
 
 
 class QueryConstructorApi:
